pub struct FeatureView {
pub enabled: BTreeSet<String>,
}Expand description
Per-package feature view consumed by super::explain_feature.
Fields
enabled: BTreeSet<String>Names of features enabled on this package by the resolver. Empty when the resolver did not visit the package.