render_explanation_json

Function render_explanation_json 

pub fn render_explanation_json(exp: &Explanation) -> Value
Render an Explanation as a stable JSON document.

Panics

Panics if the Explanation fails to serialize via serde_json::to_value, which cannot happen because Explanation derives Serialize with no fallible custom serializer.